@@ -74,6 +74,8 @@ bool Database::migrate()
         TRUE_OR_RETURN(migrateTo8());
     if (dbversion < 9)
         TRUE_OR_RETURN(migrateTo9());
+    if (dbversion < 10)
+        TRUE_OR_RETURN(migrateTo10());
     return true;
 }
 
@@ -263,6 +265,16 @@ bool Database::migrateTo9()
     return true;
 }
 
+bool Database::migrateTo10()
+{
+    qDebug() << "Migrating database to version 10";
+    TRUE_OR_RETURN(transaction());
+    TRUE_OR_RETURN(execute(QStringLiteral("ALTER TABLE Feeds ADD COLUMN filterType INTEGER DEFAULT 0;")));
+    TRUE_OR_RETURN(execute(QStringLiteral("PRAGMA user_version = 10;")));
+    TRUE_OR_RETURN(commit());
+    return true;
+}
+
 bool Database::execute(const QString &query, const QString &connectionName)
 {
     QSqlQuery q(connectionName);
