@@ -9,12 +9,14 @@
 #include "kmediasession_export.h"
 
 #include <QObject>
+#include <QQmlEngine>
 #include <QString>
 #include <QUrl>
 
 class KMEDIASESSION_EXPORT MetaData : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
 
     Q_PROPERTY(QString title READ title WRITE setTitle NOTIFY titleChanged)
     Q_PROPERTY(QString artist READ artist WRITE setArtist NOTIFY artistChanged)
@@ -23,7 +25,6 @@ class KMEDIASESSION_EXPORT MetaData : public QObject
 
 public:
     explicit MetaData(QObject *parent = nullptr);
-    ~MetaData();
 
     QString title() const;
     QString artist() const;
